\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{bidiSP}
              [2010/12/04 v0.1
 Simple Presentation class using bidi in XeLaTeX]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass{article}
%تعیین اندازه  و حاشیه‌ها برای محیط نمایش
\RequirePackage[paperheight=100mm, paperwidth=130mm, right=15mm, left=5mm, top=5mm]{geometry}
%ایجاد محیط قضیه ، تعریف، لم و ...، برای اینکار از بسته thmbox استفاده کرده‌ام، به راهنمای بسته مراجعه کنید و تغییرات مطابق سلیقه خودتان را اعمال کنید
\RequirePackage{thmbox}
\newtheorem[L,bodystyle=\slshape\yas]{thm}{قضیه}[section]
\newtheorem[L,bodystyle=\slshape\yas]{lem}[thm]{لم}
\newtheorem[L,bodystyle=\noindent\riaz]{defn}[thm]{تعریف}
\newtheorem[M,bodystyle=\slshape\yas]{cor}[thm]{نتیجه}
\newtheorem[bodystyle=\noindent\riaz]{rem}[thm]{تذکر}
%برای بیان یک مثال هم از محیط examp که در اینجا تعریف شده و هم از محیط example می‌توان استفاده نمود
\newenvironment{examp}{\begin{thmbox}[S]{\textbf{مثال:~}}}{\end{thmbox}}
\newenvironment{note}[1]{\hspace*{5mm}\shadowbox{\parbox[t]{0.9\linewidth}{\textbf{ نکته:~}\tabriz #1}}}{\\}
\newcommand{\noten}[1]{\hspace*{5mm}\shadowbox{\parbox[t]{0.9\linewidth}{\textbf{ نکته:~}
\darkgreen{\tabriz #1}}}\\}
%نام figure,table  و برهان و ... باید به کمک دستوراتی مانند زیر به معادل فارسی آنها برگردانده شود
\renewcommand{\proofname}{برهان}
\renewcommand{\examplename}{مثال}
\renewcommand{\figurename}{نگاره}
%-----------------------------------------------------
\RequirePackage{boxedminipage,color,xecolour,fancybox,hyperref,graphicx}
%تنظیمات بشسته hyperref 
\hypersetup{
pdfpagemode=FullScreen,colorlinks=true,
pdftitle={عنوان اسلاید},pdfkeywords={کلید واژه‌ها},
pdfauthor={نویسنده}, pdfsubject={موضوع},
anchorcolor={green},linktocpage=true,
pdfcreator=LaTeX with bidiSP package,pdfdisplaydoctitle,
}


\RequirePackage[RTLdocument]{bidi}
\setmainfont[Script=Arabic,Mapping=farsidigits,Scale=1]{FreeFarsi}
\newfontfamily\rmfamily[Mapping=tex-text]{XB Niloofar}
%قلم‌های مختلف برای قسمت‌های مختلف متن تعریف می‌کنیم و در دسترس قرار می‌دهیم.
%نام قلم‌ها را با آنچه خودتان مایل هستید عوض کنید
\newfontfamily\titr[Script=Arabic,Mapping=farsidigits]{XB Titre}
\newfontfamily\titrsayeh[Script=Arabic,Mapping=farsidigits]{XB Titre Shadow}
\newfontfamily\tabriz[Script=Arabic,Mapping=farsidigits]{XB Tabriz}
\newfontfamily\riaz[Script=Arabic,Mapping=farsidigits]{XB Riyaz}
\newfontfamily\roya[Script=Arabic,Mapping=farsidigits]{XB Roya}
\newfontfamily\yas[Script=Arabic,Mapping=farsidigits]{XB Yas}
%--------------------------------------------------------------------
%رنگ زمینه اسلاید در اینجا تعیین می‌شود، شما چه رنگی را ترجیح می‌دهید؟
\definecolor{bg}{rgb}{0.7,0.7,0.8}
\pagecolor{bg}
%---------------------------------------------------------------------
%اکنون این هم آن‌جایی است که کادر دور صفحه را تعریف کرده‌ایم، به راهنمای fancybox مراجعه کنید، تغییرات خودتان را اعمال کنید
%\pagestyle{empty}
\fancypage{%
  \setlength{\fboxsep}{4mm}%
%  \setlength{\shadowsize}{6mm}%
%  \setlength{\thicklines}{2mm}
  \Ovalbox}{}%\shadowbox
\linespread{1.6}
%------------------------------------------
\def\institute#1{\gdef\@institute{#1}}	  %
\def\department#1{\gdef\@department{#1}}  %
\def\slidetitle#1{\gdef\@slidetitle{#1}}  %
\def\slideauthor#1{\gdef\@slideauthor{#1}}%
\def\slidedate#1{\gdef\@slidedate{#1}}	  %
%------------------------------------------
\newcommand{\distance}[1]{\vspace*{\stretch{#1}}}
%دستور titleslide برای ایجاد صفحه اول(صفحه عنوان) بکار می رود، این آن چیزی است که من مناسب دیدم،
% شما آن را با توجه به میل و سلیقه خودتان تغییر دهد؛ خصوصا نوع قلم و اندازه آن تاثیر مهمی در زیبایی دارد.
\newcommand{\titleslide}
{{\distance{1}\centering{\titr\Huge\bfseries \@slidetitle\\
			\distance{0.1} \LARGE \@slideauthor\\
			 \@institute\\ \Large \@slidedate\distance{2}}\newpage}}
%--------------------------------------------
%در اینجا هم یک قاب ساده برای اسلاید تعریف می‌کنیم، به کمک این دستور(simpleframe) می‌توانید یک اسلاید جدید ایجاد کنید
%شما هم قاب خودتان را تعریف کنید!
\newenvironment{simpleframe}{}{\distance{1}\newpage}%
\setlength{\parskip}{1pt}
\setlength{\parindent}{0mm}
%جداکننده شماره‌ها را به خط تیره(-) پیش‌فرض آن نقطه است
\SepMark{-}
